@@ -63,6 +63,9 @@ macro_rules! methods {
                 /// Qi displays local package information: name, version, description, etc.
                 async fn qi;
 
+                /// Qii displays local packages which require X to be installed, aka local reverse dependencies.
+                async fn qii;
+
                 /// Qk verifies one or more packages.
                 async fn qk;
 
